@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2018 Canonical
+ * Copyright (C) 2014-2019 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -126,8 +126,8 @@
 #define DELAY_SET_ACTION(a1, a2, a3)	((a1 << 0) | (a2 << 1) | (a3 << 2))
 #define DELAY_GET_ACTION(n, action)	((1 << n) & action)
 
-#define FLOAT_TINY		(0.0000001)
-#define FLOAT_CMP(a, b)		(fabs((a) - (b)) < FLOAT_TINY)
+#define DOUBLE_TINY		(0.0000001)
+#define DOUBLE_CMP(a, b)		(fabs((a) - (b)) < DOUBLE_TINY)
 
 typedef struct {
 	double	divisor;			/* delay divisor */
@@ -535,10 +535,10 @@ static void stats_info(const stats_t *stats)
 			       stats->overruns + stats->perfect;
 
 		(void)fprintf(stderr, "Overruns:         %6.2f%%\n", 
-			FLOAT_CMP(total, 0.0) ?
+			DOUBLE_CMP(total, 0.0) ?
 			100.0 * (double)stats->underruns / total : 0.0);
 		(void)fprintf(stderr, "Underruns:        %6.2f%%\n",
-			FLOAT_CMP(total, 0.0) ?
+			DOUBLE_CMP(total, 0.0) ?
 			100.0 * (double)stats->overruns / total : 0.0);
 
 		(void)fprintf(stderr, "\nDrift from target rate: (%%)\n");
@@ -912,7 +912,7 @@ int main(int argc, char **argv)
 				(void)fprintf(stderr, "Data rate too high.\n");
 				exit(EXIT_BAD_OPTION);
 			}
-			if (data_rate == 0.0)
+			if (DOUBLE_CMP(data_rate, 0.0))
 				opt_flags |= OPT_NO_RATE_CONTROL;
 			else
 				opt_flags |= OPT_GOT_RATE;
